==> php54-owncloud-8.0.0.tgz: share/owncloud/apps/activity/l10n/zh_TW.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "活動",
    "Your settings have been updated." : "您的設定已更新.",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的檔案或目錄已被 <strong>建立</strong>",
    "A file or folder has been <strong>changed</strong>" : "檔案或目錄已被 <strong>變更</strong>",
    "A file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "You created %1$s" : "您建立了 %1$s",
    "%2$s created %1$s" : "%2$s 已建立 %1$s",
    "%1$s was created in a public folder" : "%1$s 已建立於公開的目錄",
    "You changed %1$s" : "您變更了 %1$s",
    "%2$s changed %1$s" : "%2$s 已變更了 %1$s",
    "You deleted %1$s" : "您刪除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 已刪除 %1$s",
    "You restored %1$s" : "您恢復了 %1$s",
    "%2$s restored %1$s" : "%2$s 已恢復了 %1$s",
    "You shared %1$s with %2$s" : "您與 %2$s 分享了 %1$s",
    "You shared %1$s with group %2$s" : "您與 %2$s 群組分享了 %1$s",
    "%2$s shared %1$s with you" : "%2$s 與您分享了 %1$s",
    "You shared %1$s via link" : "您以連結分享了 %1$s",
    "Activity notification" : "活動通知",
    "All Activities" : "所有活動",
    "Activities by you" : "您的活動",
    "Activities by others" : "其他人的活動",
    "Shares" : "分享",
    "Files" : "檔案",
    "in %s" : "在 %s",
    "%s and %s" : "%s 與 %s",
    ", " : ", ",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s 與 <strong class=\"tooltip\" title=\"%s\">%n 個</strong>"],
    "%s and %n more::%s and %n more" : ["%s 與 %n 個"],
    "Hello %s," : "哈囉 %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "您會收到郵件是因為在最近一小時發生以下的事件 %s",
    "You are receiving this email because in the last day the following things happened at %s" : "您會收到郵件是因為在最近一天發生以下的事件 %s",
    "You are receiving this email because in the last week the following things happened at %s" : "您會收到郵件是因為在最近一星期發生以下的事件 %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "當您開始使用您的 %s 時候，您將會在這看到事件列表。",
    "No more events to load" : "沒有讀取到更多事件",
    "Enable RSS feed" : "啟用 RSS feed",
    "Notifications" : "通知",
    "Mail" : "電子郵件",
    "Stream" : "串流",
    "List your own actions in the stream" : "在串流中列出您的活動狀態",
    "Notify about your own actions via email" : "透過郵件來通知有關於您的活動狀態",
    "You need to set up your email address before you can receive notification emails." : "在您可以收到通知郵件信之前您必須先設定您的電子郵件。",
    "Send emails:" : "寄送郵件:",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每週",
    "Activity feed" : "動態",
    "Personal activity feed for %s" : "個人動態 %s"
},
"nplurals=1; plural=0;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/activity/l10n/zh_TW.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "活動",
    "Personal activity feed for %s" : "個人動態 %s",
    "Your feed URL is invalid" : "您的 Feed URL是無效的",
    "Your settings have been updated." : "您的設定已更新.",
    "There are no events for this filter" : "在此篩選器下沒有活動",
    "Activity notification" : "活動通知",
    "All Activities" : "所有活動",
    "Activities by you" : "您的活動",
    "Activities by others" : "其他人的活動",
    "\"remote user\"" : "\"遠端用戶\"",
    "in %s" : "在 %s",
    "%s and %s" : "%s 與 %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s 與 <strong class=\"tooltip\" title=\"%s\">%n 個</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s 與 %n 個"],
    "Hello %s," : "哈囉 %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "您會收到郵件是因為在最近一小時發生以下的事件 %s",
    "You are receiving this email because in the last day the following things happened at %s" : "您會收到郵件是因為在最近一天發生以下的事件 %s",
    "You are receiving this email because in the last week the following things happened at %s" : "您會收到郵件是因為在最近一星期發生以下的事件 %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "Notifications" : "通知",
    "Mail" : "電子郵件",
    "Stream" : "串流",
    "List your own actions in the stream" : "在串流中列出您的活動狀態",
    "Notify about your own actions via email" : "透過郵件來通知有關於您的活動狀態",
    "You need to set up your email address before you can receive notification emails." : "在您可以收到通知郵件信之前您必須先設定您的電子郵件。",
    "Send emails:" : "寄送郵件:",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每週",
    "Activity feed" : "動態",
    "Enable RSS feed" : "啟用 RSS feed",
    "No activity yet" : "尚無活動",
    "No more events to load" : "沒有讀取到更多事件",
    "Files" : "檔案"
},
"nplurals=1; plural=0;");
